@@ -2,15 +2,15 @@ package Yars::Command::yars_fast_balance;
 
 # PODNAME: yars_fast_balance
 # ABSTRACT: Fix all files
-our $VERSION = '1.16'; # VERSION
+our $VERSION = '1.17'; # VERSION
 
 
 use strict;
 use warnings;
 use 5.010;
 use Yars::Client;
-use Log::Log4perl qw(:levels);
-use Log::Log4perl::CommandLine ':all', ':loginit' => { level => $INFO };
+use Log::Log4perl ();
+use Log::Log4perl::CommandLine ':all', ':loginit' => { level => $Log::Log4perl::INFO };
 use Clustericious::Log;
 use Clustericious::Config;
 use Hash::MoreUtils qw/safe_reverse/;
